@@ -1,4 +1,3 @@
-
 import re
 from copy import deepcopy
 from datetime import datetime
@@ -32,8 +31,7 @@ def validate_sort_specifier(sort):
 
 
 def ordering(fieldwalkers, order, doc_type=None):
-    """
-    """
+    """ """
     total = len(fieldwalkers)
     pre_sect_stack = []
 
@@ -110,18 +108,15 @@ class LogicBox(list):
 
     """
 
-    def __init__(self, theme, implicity=False):
+    def __init__(self, theme, implicitly=False):
         self.theme = theme
-        self.implicity = implicity
+        self.implicitly = implicitly
         self._logic = {
-
             "$and": self._call_and,
             "$or": self._call_or,
             "$nor": self._call_nor,
             "$not": self._call_not,
-
             "$elemMatch": self._call_elemMatch,
-
         }
 
     @property
@@ -132,7 +127,7 @@ class LogicBox(list):
         """Display `theme` and `LogicBox` or operators content within"""
         content = []
         name = "[{}]"
-        if not self.implicity:
+        if not self.implicitly:
             content = ["LogicBox({})".format(self.theme)]
             name = "{}"
 
@@ -155,7 +150,7 @@ class LogicBox(list):
         A short-circuit logic sub-structure, passing `FieldWalker` instance.
 
         Args:
-            fieldwalker (FieldWalker): Recived from `QueryFilter` instance.
+            fieldwalker (FieldWalker): Received from `QueryFilter` instance.
 
         """
         try:
@@ -172,7 +167,7 @@ class LogicBox(list):
             return all(self._gen(fieldwalker))
 
     def _call_elemMatch(self, fieldwalker):
-        """"""
+        """ """
         with fieldwalker.value as field_value:
             for elem in field_value.iter_elements():
                 field_value.change_iter(lambda: iter([elem]))
@@ -207,23 +202,18 @@ class QueryFilter(object):
 
         # Top-level operators, work on top of fields.
         self.pathless_ops = {
-
             # Logical
             "$and": self.parse_logic("$and"),
             "$nor": self.parse_logic("$nor"),
             "$or": self.parse_logic("$or"),
-
             # Evaluation
             "$expr": None,
-
         }
 
         # Field-level operators, need to work inside a field context.
         self.field_ops = {
-
             # Logical
             "$not": self._parse_not,
-
             # Comparison
             "$eq": parse_eq,
             "$gt": parse_gt,
@@ -233,21 +223,17 @@ class QueryFilter(object):
             "$lte": parse_lte,
             "$ne": parse_ne,
             "$nin": parse_nin,
-
             # Element
             "$exists": parse_exists,
             "$type": parse_type,
-
             # Array
             "$all": parse_all,
             "$elemMatch": self._parse_elemMatch,
             "$size": parse_size,
-
             # Evaluation
             "$jsonSchema": parse_jsonSchema,
             "$mod": parse_mod,
             "$regex": parse_regex,
-
         }
 
         # Start parsing query object
@@ -266,7 +252,7 @@ class QueryFilter(object):
         filter or not.
 
         Args:
-            doc (dict): Document recived from database.
+            doc (dict): Document received from database.
 
         """
         self.__fieldwalker = FieldWalker(doc, doc_type)
@@ -279,9 +265,9 @@ class QueryFilter(object):
     def parser(self, spec):
         """Top-level parser"""
 
-        # Implementation of implicity $and operation, fundamental query
+        # Implementation of implicitly $and operation, fundamental query
         # container.
-        logic_box = LogicBox("$and", implicity=True)
+        logic_box = LogicBox("$and", implicitly=True)
 
         for path, sub_spec in spec.items():
             if path.startswith("$"):
@@ -289,7 +275,8 @@ class QueryFilter(object):
                     logic_box.append(self.pathless_ops[path](sub_spec))
                 except KeyError:
                     raise OperationFailure(
-                        "unknown top level operator: {}".format(path))
+                        "unknown top level operator: {}".format(path)
+                    )
             else:
                 logic_box.append(self.subparser(path, sub_spec))
 
@@ -302,7 +289,7 @@ class QueryFilter(object):
         logic_box = LogicBox(path)
 
         # There are two processing direction in field-level, one is filtering
-        # with operators, the other is implicity value $eq operation.
+        # with operators, the other is implicitly value $eq operation.
         # The direction was first defined by the expression value type, if is
         # <dict>, then by *first* key is starts with "$" or not.
         #
@@ -338,7 +325,8 @@ class QueryFilter(object):
                     if isinstance(value, (RE_PATTERN_TYPE, bson.Regex)):
                         raise OperationFailure(
                             "Can't have RegEx as arg to predicate over "
-                            "field {!r}.".format(path))
+                            "field {!r}.".format(path)
+                        )
 
                 try:
                     logic_box.append(self.field_ops[op](value))
@@ -350,11 +338,10 @@ class QueryFilter(object):
         return logic_box
 
     def parse_logic(self, theme):
-        """Logical operator parser (un-themed)
-        """
+        """Logical operator parser (un-themed)"""
+
         def _parse_logic(sub_spec):
-            """Themed logical operator
-            """
+            """Themed logical operator"""
             if not isinstance(sub_spec, list):
                 raise OperationFailure("{} must be an array".format(theme))
 
@@ -363,7 +350,8 @@ class QueryFilter(object):
             for cond in sub_spec:
                 if not is_duckument_type(cond):
                     raise OperationFailure(
-                        "$or/$and/$nor entries need to be full objects")
+                        "$or/$and/$nor entries need to be full objects"
+                    )
 
                 logic_box.append(self.parser(cond))
             return logic_box
@@ -378,8 +366,7 @@ class QueryFilter(object):
         elif is_duckument_type(sub_spec):
             for op in sub_spec:
                 if op not in self.field_ops:
-                    raise OperationFailure("unknown operator: "
-                                           "{}".format(op))
+                    raise OperationFailure("unknown operator: {}".format(op))
                 if op == "$regex":
                     raise OperationFailure("$not cannot have a regex")
 
@@ -403,8 +390,7 @@ class QueryFilter(object):
 
 
 def _is_expression_obj(sub_spec):
-    return (is_duckument_type(sub_spec) and
-            next(iter(sub_spec)).startswith("$"))
+    return is_duckument_type(sub_spec) and next(iter(sub_spec)).startswith("$")
 
 
 # Only for preserving `int` type flags to bypass
@@ -412,6 +398,7 @@ def _is_expression_obj(sub_spec):
 class _FALG(object):
     def __init__(self, int_flags):
         self.retrieve = int_flags
+
     __slots__ = ("retrieve",)
 
 
@@ -421,8 +408,7 @@ def _regex_options_(regex_flag, opt_flag):
 
 def _regex_options_v42(regex_flag, opt_flag):
     if regex_flag and opt_flag:
-        raise OperationFailure("options set in both $regex and "
-                               "$options")
+        raise OperationFailure("options set in both $regex and $options")
 
 
 _regex_options_check = _regex_options_v42
@@ -460,7 +446,7 @@ def _modify_regex_optins(sub_spec):
     new_sub_spec = deepcopy(sub_spec)
     new_sub_spec["$regex"] = {
         "pattern": _re.pattern if _re else sub_spec["$regex"],
-        "flags": flags
+        "flags": flags,
     }
 
     # (monument): This is edge case, and only MongoDB 4.0 don't fail the
@@ -491,8 +477,9 @@ Field-level Query Operators
 
 
 def _is_comparable_ver4(val, qry):
-    return (gravity(val, weight_only=True) == gravity(qry, weight_only=True)
-            or isinstance(qry, (bson.MinKey, bson.MaxKey)))
+    return gravity(val, weight_only=True) == gravity(
+        qry, weight_only=True
+    ) or isinstance(qry, (bson.MinKey, bson.MaxKey))
 
 
 def _is_comparable_ver3(val, qry):
@@ -503,8 +490,7 @@ _is_comparable = _is_comparable_ver4
 
 
 def _eq_match(fieldwalker, query):
-    """
-    """
+    """ """
     if is_duckument_type(query):
         for val in fieldwalker.value:
             if is_duckument_type(val):
@@ -564,8 +550,7 @@ def parse_gte(query):
             if _is_comparable(value, query):
                 if query in bson.decimal128_NaN_ls:
                     return True if value in bson.decimal128_NaN_ls else False
-                if (query == bson.decimal128_INF
-                        and not value == bson.decimal128_INF):
+                if query == bson.decimal128_INF and not value == bson.decimal128_INF:
                     return False
                 if Weighted(value) >= Weighted(query):
                     return True
@@ -599,8 +584,7 @@ def parse_lte(query):
             if _is_comparable(value, query):
                 if query in bson.decimal128_NaN_ls:
                     return True if value in bson.decimal128_NaN_ls else False
-                if (query == bson.decimal128_INF
-                        and value in bson.decimal128_NaN_ls):
+                if query == bson.decimal128_INF and value in bson.decimal128_NaN_ls:
                     return False
                 if query not in _dec_NaN_INF_ls and value in _dec_NaN_INF_ls:
                     return False
@@ -613,8 +597,7 @@ def parse_lte(query):
 
 
 def _in_match(fieldwalker, query):
-    """Helper function for $in and $nin
-    """
+    """Helper function for $in and $nin"""
     q_regex = []
     q_value = []
     for q in query:
@@ -624,8 +607,7 @@ def _in_match(fieldwalker, query):
             try:
                 q_regex.append(q.try_compile())
             except re.error as e:
-                raise OperationFailure("Regular expression is invalid:"
-                                       " {}".format(e))
+                raise OperationFailure("Regular expression is invalid: {}".format(e))
         else:
             q_value.append(q)
 
@@ -760,7 +742,6 @@ def parse_exists(query):
 
 
 BSON_TYPE_ALIAS_ID = {
-
     "double": 1,
     "string": 2,
     "object": 3,
@@ -781,7 +762,7 @@ BSON_TYPE_ALIAS_ID = {
     "long": 18,
     "decimal": 19,
     "minKey": -1,
-    "maxKey": 127
+    "maxKey": 127,
 }
 
 
@@ -815,7 +796,7 @@ def obj_to_bson_type_id(obj):
         bson.Int64: 18,
         bson.Decimal128: 19,
         bson.MinKey: -1,
-        bson.MaxKey: 127
+        bson.MaxKey: 127,
     }
 
     try:
@@ -852,16 +833,15 @@ def parse_type(query):
                 try:
                     int_types.append(BSON_TYPE_ALIAS_ID[q])
                 except KeyError:
-                    raise OperationFailure(
-                        "Unknown type name alias: {}".format(q))
+                    raise OperationFailure("Unknown type name alias: {}".format(q))
             elif isinstance(q, int):
                 if q not in _BSON_TYPE_ID:
-                    raise OperationFailure(
-                        "Invalid numerical type code: {}".format(q))
+                    raise OperationFailure("Invalid numerical type code: {}".format(q))
                 int_types.append(q)
             else:
                 raise OperationFailure(
-                    "type must be represented as a number or a string")
+                    "type must be represented as a number or a string"
+                )
         return int_types
 
     if not isinstance(query, list):
