@@ -1,9 +1,18 @@
 
-from .types import (
-    BSONError,
-    InvalidDocument,
-    InvalidId,
-)
+
+def init_bson_err():
+    import sys
+    from .types import bson_ as bson
+    this = sys.modules[__name__]
+
+    class DocumentTooLarge(bson.InvalidDocument):
+        """Raised when an encoded document is too large.
+        """
+
+    setattr(this, "BSONError", bson.BSONError)
+    setattr(this, "InvalidId", bson.InvalidId)
+    setattr(this, "InvalidDocument", bson.InvalidDocument)
+    setattr(this, "DocumentTooLarge", DocumentTooLarge)
 
 
 class MontyError(Exception):
@@ -53,11 +62,6 @@ class CollectionInvalid(MontyError):
     """
 
 
-class DocumentTooLarge(InvalidDocument):
-    """Raised when an encoded document is too large.
-    """
-
-
 class WriteError(OperationFailure):
     """Base exception type for errors raised during write operations.
     """
